package com.playlet.system.service;

import java.util.List;
import com.playlet.system.domain.PlayletCustomerService;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 短剧客服管理Service接口
 *
 * @author ruoyi
 * @date 2024-03-20
 */
public interface IPlayletCustomerServiceService extends IService<PlayletCustomerService>
{
    /**
     * 查询短剧客服管理
     *
     * @param id 短剧客服管理主键
     * @return 短剧客服管理
     */
    public PlayletCustomerService selectPlayletCustomerServiceById(Long id);

    /**
     * 查询短剧客服管理列表
     *
     * @param playletCustomerService 短剧客服管理
     * @return 短剧客服管理集合
     */
    public List<PlayletCustomerService> selectPlayletCustomerServiceList(PlayletCustomerService playletCustomerService);

    /**
     * 新增短剧客服管理
     *
     * @param playletCustomerService 短剧客服管理
     * @return 结果
     */
    public int insertPlayletCustomerService(PlayletCustomerService playletCustomerService);

    /**
     * 修改短剧客服管理
     *
     * @param playletCustomerService 短剧客服管理
     * @return 结果
     */
    public int updatePlayletCustomerService(PlayletCustomerService playletCustomerService);

    /**
     * 批量删除短剧客服管理
     *
     * @param ids 需要删除的短剧客服管理主键集合
     * @return 结果
     */
    public int deletePlayletCustomerServiceByIds(String ids);

    /**
     * 删除短剧客服管理信息
     *
     * @param id 短剧客服管理主键
     * @return 结果
     */
    public int deletePlayletCustomerServiceById(Long id);
}
