package com.playlet.web.controller.system;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.playlet.common.annotation.Log;
import com.playlet.common.enums.BusinessType;
import com.playlet.system.domain.PlayletCustomerService;
import com.playlet.system.service.IPlayletCustomerServiceService;
import com.playlet.common.core.controller.BaseController;
import com.playlet.common.core.domain.AjaxResult;
import com.playlet.common.utils.poi.ExcelUtil;
import com.playlet.common.core.page.TableDataInfo;

/**
 * 短剧客服管理Controller
 *
 * @author ruoyi
 * @date 2024-03-20
 */
@Controller
@RequestMapping("/system/playlet/service")
public class PlayletCustomerServiceController extends BaseController
{
    private String prefix = "system/playlet/service";

    @Autowired
    private IPlayletCustomerServiceService playletCustomerServiceService;

    @RequiresPermissions("playlet:service:view")
    @GetMapping()
    public String service()
    {
        return prefix + "/service";
    }

    /**
     * 查询短剧客服管理列表
     */
    @RequiresPermissions("playlet:service:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(PlayletCustomerService playletCustomerService)
    {
        startPage();
        List<PlayletCustomerService> list = playletCustomerServiceService.selectPlayletCustomerServiceList(playletCustomerService);
        return getDataTable(list);
    }

    /**
     * 导出短剧客服管理列表
     */
    @RequiresPermissions("playlet:service:export")
    @Log(title = "短剧客服管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(PlayletCustomerService playletCustomerService)
    {
        List<PlayletCustomerService> list = playletCustomerServiceService.selectPlayletCustomerServiceList(playletCustomerService);
        ExcelUtil<PlayletCustomerService> util = new ExcelUtil<PlayletCustomerService>(PlayletCustomerService.class);
        return util.exportExcel(list, "短剧客服管理数据");
    }

    /**
     * 新增短剧客服管理
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存短剧客服管理
     */
    @RequiresPermissions("playlet:service:add")
    @Log(title = "短剧客服管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(PlayletCustomerService playletCustomerService)
    {
        return toAjax(playletCustomerServiceService.insertPlayletCustomerService(playletCustomerService));
    }

    /**
     * 修改短剧客服管理
     */
    @RequiresPermissions("playlet:service:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        PlayletCustomerService playletCustomerService = playletCustomerServiceService.selectPlayletCustomerServiceById(id);
        mmap.put("playletCustomerService", playletCustomerService);
        return prefix + "/edit";
    }

    /**
     * 修改保存短剧客服管理
     */
    @RequiresPermissions("playlet:service:edit")
    @Log(title = "短剧客服管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(PlayletCustomerService playletCustomerService)
    {
        return toAjax(playletCustomerServiceService.updatePlayletCustomerService(playletCustomerService));
    }

    /**
     * 删除短剧客服管理
     */
    @RequiresPermissions("playlet:service:remove")
    @Log(title = "短剧客服管理", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(playletCustomerServiceService.deletePlayletCustomerServiceByIds(ids));
    }
}
